import { Prop, Provide, Emit, Model } from 'vue-property-decorator';
import { Subject, Subscription } from 'rxjs';
import { Watch, GridControlBase } from '@/studio-core';
import HRWorkRecordService from '@/service/hrwork-record/hrwork-record-service';
import MainService from './main-grid-service';
import HRWorkRecordUIService from '@/uiservice/hrwork-record/hrwork-record-ui-service';
import { FormItemModel } from '@/model/form-detail';


/**
 * grid部件基类
 *
 * @export
 * @class GridControlBase
 * @extends {MainGridBase}
 */
export class MainGridBase extends GridControlBase {

    /**
     * 获取部件类型
     *
     * @protected
     * @type {string}
     * @memberof MainGridBase
     */
    protected controlType: string = 'GRID';

    /**
     * 建构部件服务对象
     *
     * @type {MainService}
     * @memberof MainGridBase
     */
    public service: MainService = new MainService({ $store: this.$store });

    /**
     * 实体服务对象
     *
     * @type {HRWorkRecordService}
     * @memberof MainGridBase
     */
    public appEntityService: HRWorkRecordService = new HRWorkRecordService({ $store: this.$store });

    /**
     * 应用实体名称
     *
     * @protected
     * @type {string}
     * @memberof MainGridBase
     */
    protected appDeName: string = 'hrworkrecord';

    /**
     * 应用实体中文名称
     *
     * @protected
     * @type {string}
     * @memberof MainGridBase
     */
    protected appDeLogicName: string = '工作履历';

    /**
     * 界面UI服务对象
     *
     * @type {HRWorkRecordUIService}
     * @memberof MainBase
     */  
    public appUIService:HRWorkRecordUIService = new HRWorkRecordUIService(this.$store);

    /**
     * 界面行为模型
     *
     * @type {*}
     * @memberof MainBase
     */  
    public ActionModel: any = {
    };

    /**
     * 本地缓存标识
     *
     * @protected
     * @type {string}
     * @memberof MainBase
     */
    protected localStorageTag: string = 'hrworkrecord_main_grid';

    /**
     * 所有列成员
     *
     * @type {any[]}
     * @memberof MainGridBase
     */
    public allColumns: any[] = [
        {
            name: 'begintime',
            label: '开始时间',
            langtag: 'entities.hrworkrecord.main_grid.columns.begintime',
            show: true,
            util: 'PX',
            isEnableRowEdit: false,
        },
        {
            name: 'endtime',
            label: '结束时间',
            langtag: 'entities.hrworkrecord.main_grid.columns.endtime',
            show: true,
            util: 'PX',
            isEnableRowEdit: false,
        },
        {
            name: 'workorganization',
            label: '工作单位',
            langtag: 'entities.hrworkrecord.main_grid.columns.workorganization',
            show: true,
            util: 'PX',
            isEnableRowEdit: false,
        },
        {
            name: 'workdepartment',
            label: '部门',
            langtag: 'entities.hrworkrecord.main_grid.columns.workdepartment',
            show: true,
            util: 'PX',
            isEnableRowEdit: false,
        },
        {
            name: 'duty',
            label: '职务',
            langtag: 'entities.hrworkrecord.main_grid.columns.duty',
            show: true,
            util: 'PX',
            isEnableRowEdit: false,
        },
        {
            name: 'post',
            label: '职位',
            langtag: 'entities.hrworkrecord.main_grid.columns.post',
            show: true,
            util: 'PX',
            isEnableRowEdit: false,
        },
        {
            name: 'mainwork',
            label: '主要经历',
            langtag: 'entities.hrworkrecord.main_grid.columns.mainwork',
            show: true,
            util: 'PX',
            isEnableRowEdit: false,
        },
    ]

    /**
     * 获取表格行模型
     *
     * @type {*}
     * @memberof MainGridBase
     */
    public getGridRowModel(){
        return {
          srfkey: new FormItemModel(),
        }
    }

    /**
     * 属性值规则
     *
     * @type {*}
     * @memberof MainGridBase
     */
    public rules: any = {
        srfkey: [
            { required: false, validator: (rule:any, value:any, callback:any) => { return (rule.required && (value === null || value === undefined || value === "")) ? false : true;}, message: '工作履历标识 值不能为空', trigger: 'change' },
            { required: false, validator: (rule:any, value:any, callback:any) => { return (rule.required && (value === null || value === undefined || value === "")) ? false : true;}, message: '工作履历标识 值不能为空', trigger: 'blur' },
        ],
    }

    /**
     * 获取对应列class
     *
     * @type {*}
     * @memberof MainBase
     */
    public hasRowEdit: any = {
        'begintime':false,
        'endtime':false,
        'workorganization':false,
        'workdepartment':false,
        'duty':false,
        'post':false,
        'mainwork':false,
    };

    /**
     * 获取对应列class
     *
     * @param {*} $args row 行数据，column 列数据，rowIndex 行索引，列索引
     * @returns {void}
     * @memberof MainBase
     */
    public getCellClassName(args: {row: any, column: any, rowIndex: number, columnIndex: number}): any {
        return ( this.hasRowEdit[args.column.property] && this.actualIsOpenEdit ) ? "edit-cell" : "info-cell";
    }


    /**
     * 导出数据格式化
     *
     * @param {*} filterVal
     * @param {*} jsonData
     * @param {any[]} [codelistColumns=[]]
     * @returns {Promise<any>}
     * @memberof MainGridBase
     */
    public async formatExcelData(filterVal: any, jsonData: any, codelistColumns?: any[]): Promise<any> {
        return super.formatExcelData(filterVal, jsonData, [
            {
                name: 'mainwork',
                srfkey: 'YesNo',
                codelistType : 'STATIC',
                renderMode: 'other',
                textSeparator: '、',
                valueSeparator: ',',
            },
        ]);
    }

}